Local
=====

Template ID: ``local``



Quickstart
-----------

Take note below how to configure the template. This quickstart only includes the fields you absolutely require. This will write a new configuration to ``~/.janis.conf``. See `configuring janis <https://janis.readthedocs.io/en/latest/references/configuration.html>`__ for more information.

.. code-block:: bash

   janis init local
   
   # or to find out more information
   janis init local --help

OR you can insert the following lines into your template:

.. code-block:: yaml

   template:
     id: local



Fields
-------



**Optional**

====  ======  =========  ===============
ID    Type    Default    Documentation
====  ======  =========  ===============
====  ======  =========  ===============

